@@ -4,7 +4,7 @@ import re
 import argparse
 import pathlib  # python 3.4
 
-__version__ = '1.3.1'
+__version__ = '1.4.0'
 
 
 def process_file(filename_in, filename_out):
@@ -16,7 +16,8 @@ def process_file(filename_in, filename_out):
     item_re = re.compile(r'^(\s*)-((?:<[^>]*>)?)((?:\[[^\]]*\])?) (.*)$')
     enumitem_re = re.compile(r'^(\s*)#((?:<[^>]*>)?)((?:\[[^\]]*\])?) (.*)$')
     column_re = re.compile(r'^(\s*)c((?:\[[^\]]*\])?)\{([^}]*)\}(.*)$')
-    figure_re = re.compile(r'^(\s*)f((?:<[^>]*>)?)\{([^}]*)\}\{([^}]*)\}(.*)$')
+    figure_re = re.compile(r'^(\s*)f((?:<[^>]*>)?)\{([^}]*)\}(?:\[([^\]]*)\])?'
+                           r'\{([^}]*)\}(.*)$')
     empty_re = re.compile(r'^\s*$')
     end_re = re.compile(r'^\s*\\end\{[^}]*\}.*$')
     non_empty_re = re.compile(r'(\s*)\S.*$')
@@ -126,14 +127,21 @@ def process_file(filename_in, filename_out):
             figure = figure_re.match(line)
             figure_indent = len(figure.group(1))
             figure_ratio = figure.group(3)
-            figure_fname = figure.group(4)
-            figure_rest = figure.group(5)
+            figure_fname = figure.group(5)
+            figure_rest = figure.group(6)
             figure_overlay = figure.group(2)
+            figure_options = figure.group(4)
+            if figure_options is None:
+                figure_options = ''
+            else:
+                figure_options = ',' + figure_options
             close_envs(figure_indent)
             lines.append(
                 indent() +
-                '\\includegraphics{}[width={}\\columnwidth]{{{}}}{}\n'.format(
-                    figure_overlay, figure_ratio, figure_fname, figure_rest))
+                '\\includegraphics{}[width={}\\columnwidth{}]{{{}}}{}\n'
+                .format(
+                    figure_overlay, figure_ratio, figure_options,
+                    figure_fname, figure_rest))
         elif itemize_re.match(line):  # itemize environment
             itemize = itemize_re.match(line)
             itemize_indent = len(itemize.group(1))
